# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud.trino.v1 import access_control_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_access__control__pb2
from yandex.cloud.trino.v1 import maintenance_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/trino/v1/cluster.proto\x12\x15yandex.cloud.trino.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a*yandex/cloud/trino/v1/access_control.proto\x1a\'yandex/cloud/trino/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"\x89\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.trino.v1.Cluster.LabelsEntry\x12\x35\n\nmonitoring\x18\x07 \x03(\x0b\x32!.yandex.cloud.trino.v1.Monitoring\x12\x31\n\x05trino\x18\x08 \x01(\x0b\x32\".yandex.cloud.trino.v1.TrinoConfig\x12-\n\x06health\x18\t \x01(\x0e\x32\x1d.yandex.cloud.trino.v1.Health\x12\x35\n\x06status\x18\n \x01(\x0e\x32%.yandex.cloud.trino.v1.Cluster.Status\x12\x35\n\x07network\x18\x0b \x01(\x0b\x32$.yandex.cloud.trino.v1.NetworkConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12$\n\x12service_account_id\x18\r \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\x0e \x01(\x0b\x32$.yandex.cloud.trino.v1.LoggingConfig\x12\x17\n\x0f\x63oordinator_url\x18\x0f \x01(\t\x12\x44\n\x12maintenance_window\x18\x10 \x01(\x0b\x32(.yandex.cloud.trino.v1.MaintenanceWindow\x12\x46\n\x11planned_operation\x18\x11 \x01(\x0b\x32+.yandex.cloud.trino.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xe2\x01\n\rLoggingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x38\n\tfolder_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12;\n\x0clog_group_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\"?\n\rNetworkConfig\x12\x12\n\nsubnet_ids\x18\x01 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\"\xb0\x02\n\x0bTrinoConfig\x12J\n\x12\x63oordinator_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.trino.v1.CoordinatorConfigB\x04\xe8\xc7\x31\x01\x12@\n\rworker_config\x18\x02 \x01(\x0b\x32#.yandex.cloud.trino.v1.WorkerConfigB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07version\x18\x03 \x01(\t\x12>\n\x0cretry_policy\x18\x04 \x01(\x0b\x32(.yandex.cloud.trino.v1.RetryPolicyConfig\x12\x42\n\x0e\x61\x63\x63\x65ss_control\x18\x05 \x01(\x0b\x32*.yandex.cloud.trino.v1.AccessControlConfig\"N\n\x11\x43oordinatorConfig\x12\x39\n\tresources\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.ResourcesB\x04\xe8\xc7\x31\x01\"\xc4\x02\n\x0cWorkerConfig\x12\x39\n\tresources\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12Q\n\x0cscale_policy\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.WorkerConfig.WorkerScalePolicyB\x04\xe8\xc7\x31\x01\x1a\xa5\x01\n\x11WorkerScalePolicy\x12>\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32\'.yandex.cloud.trino.v1.FixedScalePolicyH\x00\x12<\n\nauto_scale\x18\x02 \x01(\x0b\x32&.yandex.cloud.trino.v1.AutoScalePolicyH\x00\x42\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"\xcf\x03\n\x11RetryPolicyConfig\x12\x44\n\x06policy\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.trino.v1.RetryPolicyConfig.RetryPolicy\x12\x46\n\x10\x65xchange_manager\x18\x02 \x01(\x0b\x32,.yandex.cloud.trino.v1.ExchangeManagerConfig\x12\xac\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.trino.v1.RetryPolicyConfig.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x0bRetryPolicy\x12\x1c\n\x18RETRY_POLICY_UNSPECIFIED\x10\x00\x12\t\n\x05QUERY\x10\x01\x12\x08\n\x04TASK\x10\x02\"\x82\x01\n\x16\x45xchangeManagerStorage\x12M\n\nservice_s3\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.trino.v1.ExchangeManagerStorage.ServiceS3H\x00\x1a\x0b\n\tServiceS3B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc7\x02\n\x15\x45xchangeManagerConfig\x12\xb0\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x46.yandex.cloud.trino.v1.ExchangeManagerConfig.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x12>\n\x07storage\x18\x02 \x01(\x0b\x32-.yandex.cloud.trino.v1.ExchangeManagerStorage\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\tResources\x12(\n\x12resource_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\",\n\x10\x46ixedScalePolicy\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\"M\n\x0f\x41utoScalePolicy\x12\x1c\n\tmin_count\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12\x1c\n\tmax_count\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512*?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_TRINOCONFIG'].fields_by_name['coordinator_config']._loaded_options = None
  _globals['_TRINOCONFIG'].fields_by_name['coordinator_config']._serialized_options = b'\350\3071\001'
  _globals['_TRINOCONFIG'].fields_by_name['worker_config']._loaded_options = None
  _globals['_TRINOCONFIG'].fields_by_name['worker_config']._serialized_options = b'\350\3071\001'
  _globals['_COORDINATORCONFIG'].fields_by_name['resources']._loaded_options = None
  _globals['_COORDINATORCONFIG'].fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _globals['_WORKERCONFIG_WORKERSCALEPOLICY'].oneofs_by_name['scale_type']._loaded_options = None
  _globals['_WORKERCONFIG_WORKERSCALEPOLICY'].oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _globals['_WORKERCONFIG'].fields_by_name['resources']._loaded_options = None
  _globals['_WORKERCONFIG'].fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _globals['_WORKERCONFIG'].fields_by_name['scale_policy']._loaded_options = None
  _globals['_WORKERCONFIG'].fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _globals['_RETRYPOLICYCONFIG_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_RETRYPOLICYCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_RETRYPOLICYCONFIG'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_RETRYPOLICYCONFIG'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_EXCHANGEMANAGERSTORAGE'].oneofs_by_name['type']._loaded_options = None
  _globals['_EXCHANGEMANAGERSTORAGE'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_EXCHANGEMANAGERCONFIG_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_EXCHANGEMANAGERCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_EXCHANGEMANAGERCONFIG'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_EXCHANGEMANAGERCONFIG'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_RESOURCES'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FIXEDSCALEPOLICY'].fields_by_name['count']._loaded_options = None
  _globals['_FIXEDSCALEPOLICY'].fields_by_name['count']._serialized_options = b'\372\3071\0051-512'
  _globals['_AUTOSCALEPOLICY'].fields_by_name['min_count']._loaded_options = None
  _globals['_AUTOSCALEPOLICY'].fields_by_name['min_count']._serialized_options = b'\372\3071\0050-512'
  _globals['_AUTOSCALEPOLICY'].fields_by_name['max_count']._loaded_options = None
  _globals['_AUTOSCALEPOLICY'].fields_by_name['max_count']._serialized_options = b'\372\3071\0051-512'
  _globals['_HEALTH']._serialized_start=3340
  _globals['_HEALTH']._serialized_end=3403
  _globals['_CLUSTER']._serialized_start=253
  _globals['_CLUSTER']._serialized_end=1158
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=990
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1035
  _globals['_CLUSTER_STATUS']._serialized_start=1037
  _globals['_CLUSTER_STATUS']._serialized_end=1158
  _globals['_MONITORING']._serialized_start=1160
  _globals['_MONITORING']._serialized_end=1221
  _globals['_LOGGINGCONFIG']._serialized_start=1224
  _globals['_LOGGINGCONFIG']._serialized_end=1450
  _globals['_NETWORKCONFIG']._serialized_start=1452
  _globals['_NETWORKCONFIG']._serialized_end=1515
  _globals['_TRINOCONFIG']._serialized_start=1518
  _globals['_TRINOCONFIG']._serialized_end=1822
  _globals['_COORDINATORCONFIG']._serialized_start=1824
  _globals['_COORDINATORCONFIG']._serialized_end=1902
  _globals['_WORKERCONFIG']._serialized_start=1905
  _globals['_WORKERCONFIG']._serialized_end=2229
  _globals['_WORKERCONFIG_WORKERSCALEPOLICY']._serialized_start=2064
  _globals['_WORKERCONFIG_WORKERSCALEPOLICY']._serialized_end=2229
  _globals['_RETRYPOLICYCONFIG']._serialized_start=2232
  _globals['_RETRYPOLICYCONFIG']._serialized_end=2695
  _globals['_RETRYPOLICYCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_start=2570
  _globals['_RETRYPOLICYCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_end=2629
  _globals['_RETRYPOLICYCONFIG_RETRYPOLICY']._serialized_start=2631
  _globals['_RETRYPOLICYCONFIG_RETRYPOLICY']._serialized_end=2695
  _globals['_EXCHANGEMANAGERSTORAGE']._serialized_start=2698
  _globals['_EXCHANGEMANAGERSTORAGE']._serialized_end=2828
  _globals['_EXCHANGEMANAGERSTORAGE_SERVICES3']._serialized_start=2803
  _globals['_EXCHANGEMANAGERSTORAGE_SERVICES3']._serialized_end=2814
  _globals['_EXCHANGEMANAGERCONFIG']._serialized_start=2831
  _globals['_EXCHANGEMANAGERCONFIG']._serialized_end=3158
  _globals['_EXCHANGEMANAGERCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_start=2570
  _globals['_EXCHANGEMANAGERCONFIG_ADDITIONALPROPERTIESENTRY']._serialized_end=2629
  _globals['_RESOURCES']._serialized_start=3160
  _globals['_RESOURCES']._serialized_end=3213
  _globals['_FIXEDSCALEPOLICY']._serialized_start=3215
  _globals['_FIXEDSCALEPOLICY']._serialized_end=3259
  _globals['_AUTOSCALEPOLICY']._serialized_start=3261
  _globals['_AUTOSCALEPOLICY']._serialized_end=3338
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TrinoAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def user_password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth: ...
    def __init__(
        self,
        *,
        user_password: yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["user_password"] | None: ...

global___TrinoAuth = TrinoAuth

@typing.final
class TrinoCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Coordinator(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["host", b"host", "port", b"port"]) -> None: ...

    COORDINATOR_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def coordinator(self) -> global___TrinoCluster.Coordinator: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        coordinator: global___TrinoCluster.Coordinator | None = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["coordinator", b"coordinator", "tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["coordinator", b"coordinator", "tls_params", b"tls_params"]) -> None: ...

global___TrinoCluster = TrinoCluster

@typing.final
class TrinoConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> global___TrinoCluster: ...
    @property
    def auth(self) -> global___TrinoAuth: ...
    def __init__(
        self,
        *,
        cluster: global___TrinoCluster | None = ...,
        auth: global___TrinoAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> None: ...

global___TrinoConnection = TrinoConnection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.loadtesting.api.v1.regression.widget_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Dashboard(google.protobuf.message.Message):
    """Regression dashboard."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Content(google.protobuf.message.Message):
        """Content of regression dashboard."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        WIDGETS_FIELD_NUMBER: builtins.int
        @property
        def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.regression.widget_pb2.Widget]:
            """Widgets."""

        def __init__(
            self,
            *,
            widgets: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.regression.widget_pb2.Widget] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["widgets", b"widgets"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    UPDATED_BY_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the dashboard."""
    name: builtins.str
    """Name of the dashboard."""
    description: builtins.str
    """Description of the dashboard."""
    created_by: builtins.str
    """UA or SA that created the dashboard."""
    updated_by: builtins.str
    """UA or SA that updated the dashboard last time."""
    etag: builtins.str
    """Etag of the dashboard."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last update timestamp."""

    @property
    def content(self) -> global___Dashboard.Content:
        """Dashboard content."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        updated_by: builtins.str = ...,
        etag: builtins.str = ...,
        content: global___Dashboard.Content | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "etag", b"etag", "id", b"id", "name", b"name", "updated_at", b"updated_at", "updated_by", b"updated_by"]) -> None: ...

global___Dashboard = Dashboard



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/server_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/server_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import server_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__pb2
from yandex.cloud.baremetal.v1alpha import storage_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_storage__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/baremetal/v1alpha/server_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a+yandex/cloud/baremetal/v1alpha/server.proto\x1a,yandex/cloud/baremetal/v1alpha/storage.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"?\n\x10GetServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"\x9e\x01\n\x11ListServerRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"l\n\x12ListServerResponse\x12\x37\n\x07servers\x18\x01 \x03(\x0b\x32&.yandex.cloud.baremetal.v1alpha.Server\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x90\x05\n\x13\x43reateServerRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-56\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\"\n\x10hardware_pool_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=20\x12\x32\n\x10\x63onfiguration_id\x18\x05 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\"\n\x10rental_period_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=20\x12Y\n\x12network_interfaces\x18\x0f \x03(\x0b\x32\x34.yandex.cloud.baremetal.v1alpha.NetworkInterfaceSpecB\x07\x82\xc8\x31\x03<=2\x12H\n\x10os_settings_spec\x18\x10 \x01(\x0b\x32..yandex.cloud.baremetal.v1alpha.OsSettingsSpec\x12\x8d\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32?.yandex.cloud.baremetal.v1alpha.CreateServerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x0bJ\x04\x08\x0c\x10\x0fJ\x05\x08\x11\x10\xc8\x01\")\n\x14\x43reateServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"\xeb\x03\n\x13UpdateServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12Y\n\x12network_interfaces\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.baremetal.v1alpha.NetworkInterfaceSpecB\x07\x82\xc8\x31\x03\x31-2\x12\x8d\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32?.yandex.cloud.baremetal.v1alpha.UpdateServerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x06\x10\xc8\x01\"\x81\x02\n\x14NetworkInterfaceSpec\x12)\n\x02id\x18\x01 \x01(\tB\x1d\xf2\xc7\x31\x11([a-z][a-z0-9]*)?\x8a\xc8\x31\x04<=20\x12W\n\x0eprivate_subnet\x18\x07 \x01(\x0b\x32=.yandex.cloud.baremetal.v1alpha.PrivateSubnetNetworkInterfaceH\x00\x12U\n\rpublic_subnet\x18\x08 \x01(\x0b\x32<.yandex.cloud.baremetal.v1alpha.PublicSubnetNetworkInterfaceH\x00\x42\x08\n\x06subnetJ\x04\x08\x02\x10\x07\")\n\x14UpdateServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"B\n\x13\x44\x65leteServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\")\n\x14\x44\x65leteServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"D\n\x15PowerOffServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"+\n\x16PowerOffServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"C\n\x14PowerOnServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"*\n\x15PowerOnServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"B\n\x13RebootServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\")\n\x14RebootServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"\xa7\x01\n\x16ReinstallServerRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12H\n\x10os_settings_spec\x18\t \x01(\x0b\x32..yandex.cloud.baremetal.v1alpha.OsSettingsSpecJ\x04\x08\x02\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\x06\x10\x07\",\n\x17ReinstallServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"\x82\x01\n\x1bListServerOperationsRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"t\n\x1cListServerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xbf\x05\n\x19\x42\x61tchCreateServersRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-56\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\"\n\x10hardware_pool_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=20\x12\x32\n\x10\x63onfiguration_id\x18\x05 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\"\n\x10rental_period_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=20\x12Y\n\x12network_interfaces\x18\x0f \x03(\x0b\x32\x34.yandex.cloud.baremetal.v1alpha.NetworkInterfaceSpecB\x07\x82\xc8\x31\x03<=2\x12H\n\x10os_settings_spec\x18\x10 \x01(\x0b\x32..yandex.cloud.baremetal.v1alpha.OsSettingsSpec\x12\x93\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x45.yandex.cloud.baremetal.v1alpha.BatchCreateServersRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x19\n\x05\x63ount\x18\xac\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x0bJ\x04\x08\x0c\x10\x0fJ\x05\x08\x11\x10\xc8\x01J\x06\x08\xc9\x01\x10\xac\x02\"U\n\x1a\x42\x61tchCreateServersResponse\x12\x37\n\x07servers\x18\x01 \x03(\x0b\x32&.yandex.cloud.baremetal.v1alpha.Server\"0\n\x1a\x42\x61tchCreateServersMetadata\x12\x12\n\nserver_ids\x18\x01 \x03(\t\"-\n\x18QuarantineServerMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"G\n\x18StartProlongationRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"F\n\x17StopProlongationRequest\x12+\n\tserver_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"2\n\x1dServerSetProlongationMetadata\x12\x11\n\tserver_id\x18\x01 \x01(\t\"\xea\x02\n\x0eOsSettingsSpec\x12,\n\x08image_id\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x04<=20\x12\x39\n\x08storages\x18\x02 \x03(\x0b\x32\'.yandex.cloud.baremetal.v1alpha.Storage\x12%\n\x0essh_public_key\x18\x04 \x01(\tB\x0b\x8a\xc8\x31\x07<=20000H\x00\x12\x1f\n\x0buser_ssh_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12&\n\x13password_plain_text\x18\n \x01(\tB\x07\x8a\xc8\x31\x03>=6H\x01\x12P\n\x17password_lockbox_secret\x18\x0b \x01(\x0b\x32-.yandex.cloud.baremetal.v1alpha.LockboxSecretH\x01\x42\x0f\n\x07ssh_key\x12\x04\xc0\xc1\x31\x01\x42\x10\n\x08password\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x04J\x04\x08\x06\x10\n\"O\n\rLockboxSecret\x12\x17\n\tsecret_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x11\n\x03key\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xd2\x12\n\rServerService\x12\x8f\x01\n\x03Get\x12\x30.yandex.cloud.baremetal.v1alpha.GetServerRequest\x1a&.yandex.cloud.baremetal.v1alpha.Server\".\x82\xd3\xe4\x93\x02(\x12&/baremetal/v1alpha/servers/{server_id}\x12\x91\x01\n\x04List\x12\x31.yandex.cloud.baremetal.v1alpha.ListServerRequest\x1a\x32.yandex.cloud.baremetal.v1alpha.ListServerResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/baremetal/v1alpha/servers\x12\xa9\x01\n\x06\x43reate\x12\x33.yandex.cloud.baremetal.v1alpha.CreateServerRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x1e\n\x14\x43reateServerMetadata\x12\x06Server\x82\xd3\xe4\x93\x02\x1f\"\x1a/baremetal/v1alpha/servers:\x01*\x12\xda\x01\n\x0b\x42\x61tchCreate\x12\x39.yandex.cloud.baremetal.v1alpha.BatchCreateServersRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*8\n\x1a\x42\x61tchCreateServersMetadata\x12\x1a\x42\x61tchCreateServersResponse\x82\xd3\xe4\x93\x02+\"&/baremetal/v1alpha/servers:batchCreate:\x01*\x12\xb5\x01\n\x06Update\x12\x33.yandex.cloud.baremetal.v1alpha.UpdateServerRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*\x1e\n\x14UpdateServerMetadata\x12\x06Server\x82\xd3\xe4\x93\x02+2&/baremetal/v1alpha/servers/{server_id}:\x01*\x12\xd3\x01\n\x08PowerOff\x12\x35.yandex.cloud.baremetal.v1alpha.PowerOffServerRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*/\n\x16PowerOffServerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34\"//baremetal/v1alpha/servers/{server_id}:powerOff:\x01*\x12\xcf\x01\n\x07PowerOn\x12\x34.yandex.cloud.baremetal.v1alpha.PowerOnServerRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*.\n\x15PowerOnServerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33\"./baremetal/v1alpha/servers/{server_id}:powerOn:\x01*\x12\xcb\x01\n\x06Reboot\x12\x33.yandex.cloud.baremetal.v1alpha.RebootServerRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*-\n\x14RebootServerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32\"-/baremetal/v1alpha/servers/{server_id}:reboot:\x01*\x12\xd7\x01\n\tReinstall\x12\x36.yandex.cloud.baremetal.v1alpha.ReinstallServerRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*0\n\x17ReinstallServerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35\"0/baremetal/v1alpha/servers/{server_id}:reinstall:\x01*\x12\xe0\x01\n\x11StartProlongation\x12\x38.yandex.cloud.baremetal.v1alpha.StartProlongationRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*\'\n\x1dServerSetProlongationMetadata\x12\x06Server\x82\xd3\xe4\x93\x02=\"8/baremetal/v1alpha/servers/{server_id}:startProlongation:\x01*\x12\xdd\x01\n\x10StopProlongation\x12\x37.yandex.cloud.baremetal.v1alpha.StopProlongationRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*\'\n\x1dServerSetProlongationMetadata\x12\x06Server\x82\xd3\xe4\x93\x02<\"7/baremetal/v1alpha/servers/{server_id}:stopProlongation:\x01*\x12\xc6\x01\n\x0eListOperations\x12;.yandex.cloud.baremetal.v1alpha.ListServerOperationsRequest\x1a<.yandex.cloud.baremetal.v1alpha.ListServerOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/baremetal/v1alpha/servers/{server_id}/operationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.server_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_GETSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTSERVERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSERVERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTSERVERREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVERREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATESERVERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATESERVERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESERVERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CREATESERVERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-56'
  _globals['_CREATESERVERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATESERVERREQUEST'].fields_by_name['hardware_pool_id']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['hardware_pool_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_CREATESERVERREQUEST'].fields_by_name['configuration_id']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['configuration_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_CREATESERVERREQUEST'].fields_by_name['rental_period_id']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['rental_period_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_CREATESERVERREQUEST'].fields_by_name['network_interfaces']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['network_interfaces']._serialized_options = b'\202\3101\003<=2'
  _globals['_CREATESERVERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATESERVERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATESERVERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESERVERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_UPDATESERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_UPDATESERVERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESERVERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATESERVERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESERVERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATESERVERREQUEST'].fields_by_name['network_interfaces']._loaded_options = None
  _globals['_UPDATESERVERREQUEST'].fields_by_name['network_interfaces']._serialized_options = b'\202\3101\0031-2'
  _globals['_UPDATESERVERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATESERVERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['id']._loaded_options = None
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['id']._serialized_options = b'\362\3071\021([a-z][a-z0-9]*)?\212\3101\004<=20'
  _globals['_DELETESERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_DELETESERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_POWEROFFSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_POWEROFFSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_POWERONSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_POWERONSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_REBOOTSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_REBOOTSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_REINSTALLSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_REINSTALLSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTSERVEROPERATIONSREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_LISTSERVEROPERATIONSREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTSERVEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_BATCHCREATESERVERSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-56'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['hardware_pool_id']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['hardware_pool_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['configuration_id']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['configuration_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['rental_period_id']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['rental_period_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['network_interfaces']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['network_interfaces']._serialized_options = b'\202\3101\003<=2'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['count']._loaded_options = None
  _globals['_BATCHCREATESERVERSREQUEST'].fields_by_name['count']._serialized_options = b'\372\3071\0051-100'
  _globals['_STARTPROLONGATIONREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_STARTPROLONGATIONREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_STOPPROLONGATIONREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_STOPPROLONGATIONREQUEST'].fields_by_name['server_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_OSSETTINGSSPEC'].oneofs_by_name['ssh_key']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].oneofs_by_name['ssh_key']._serialized_options = b'\300\3011\001'
  _globals['_OSSETTINGSSPEC'].oneofs_by_name['password']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].oneofs_by_name['password']._serialized_options = b'\300\3011\001'
  _globals['_OSSETTINGSSPEC'].fields_by_name['image_id']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].fields_by_name['image_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\004<=20'
  _globals['_OSSETTINGSSPEC'].fields_by_name['ssh_public_key']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].fields_by_name['ssh_public_key']._serialized_options = b'\212\3101\007<=20000'
  _globals['_OSSETTINGSSPEC'].fields_by_name['user_ssh_id']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].fields_by_name['user_ssh_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_OSSETTINGSSPEC'].fields_by_name['password_plain_text']._loaded_options = None
  _globals['_OSSETTINGSSPEC'].fields_by_name['password_plain_text']._serialized_options = b'\212\3101\003>=6'
  _globals['_LOCKBOXSECRET'].fields_by_name['secret_id']._loaded_options = None
  _globals['_LOCKBOXSECRET'].fields_by_name['secret_id']._serialized_options = b'\350\3071\001'
  _globals['_LOCKBOXSECRET'].fields_by_name['key']._loaded_options = None
  _globals['_LOCKBOXSECRET'].fields_by_name['key']._serialized_options = b'\350\3071\001'
  _globals['_SERVERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/baremetal/v1alpha/servers/{server_id}'
  _globals['_SERVERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/baremetal/v1alpha/servers'
  _globals['_SERVERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateServerMetadata\022\006Server\202\323\344\223\002\037\"\032/baremetal/v1alpha/servers:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['BatchCreate']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['BatchCreate']._serialized_options = b'\262\322*8\n\032BatchCreateServersMetadata\022\032BatchCreateServersResponse\202\323\344\223\002+\"&/baremetal/v1alpha/servers:batchCreate:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateServerMetadata\022\006Server\202\323\344\223\002+2&/baremetal/v1alpha/servers/{server_id}:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['PowerOff']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['PowerOff']._serialized_options = b'\262\322*/\n\026PowerOffServerMetadata\022\025google.protobuf.Empty\202\323\344\223\0024\"//baremetal/v1alpha/servers/{server_id}:powerOff:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['PowerOn']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['PowerOn']._serialized_options = b'\262\322*.\n\025PowerOnServerMetadata\022\025google.protobuf.Empty\202\323\344\223\0023\"./baremetal/v1alpha/servers/{server_id}:powerOn:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['Reboot']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['Reboot']._serialized_options = b'\262\322*-\n\024RebootServerMetadata\022\025google.protobuf.Empty\202\323\344\223\0022\"-/baremetal/v1alpha/servers/{server_id}:reboot:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['Reinstall']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['Reinstall']._serialized_options = b'\262\322*0\n\027ReinstallServerMetadata\022\025google.protobuf.Empty\202\323\344\223\0025\"0/baremetal/v1alpha/servers/{server_id}:reinstall:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['StartProlongation']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['StartProlongation']._serialized_options = b'\262\322*\'\n\035ServerSetProlongationMetadata\022\006Server\202\323\344\223\002=\"8/baremetal/v1alpha/servers/{server_id}:startProlongation:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['StopProlongation']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['StopProlongation']._serialized_options = b'\262\322*\'\n\035ServerSetProlongationMetadata\022\006Server\202\323\344\223\002<\"7/baremetal/v1alpha/servers/{server_id}:stopProlongation:\001*'
  _globals['_SERVERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_SERVERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0023\0221/baremetal/v1alpha/servers/{server_id}/operations'
  _globals['_GETSERVERREQUEST']._serialized_start=347
  _globals['_GETSERVERREQUEST']._serialized_end=410
  _globals['_LISTSERVERREQUEST']._serialized_start=413
  _globals['_LISTSERVERREQUEST']._serialized_end=571
  _globals['_LISTSERVERRESPONSE']._serialized_start=573
  _globals['_LISTSERVERRESPONSE']._serialized_end=681
  _globals['_CREATESERVERREQUEST']._serialized_start=684
  _globals['_CREATESERVERREQUEST']._serialized_end=1340
  _globals['_CREATESERVERREQUEST_LABELSENTRY']._serialized_start=1276
  _globals['_CREATESERVERREQUEST_LABELSENTRY']._serialized_end=1321
  _globals['_CREATESERVERMETADATA']._serialized_start=1342
  _globals['_CREATESERVERMETADATA']._serialized_end=1383
  _globals['_UPDATESERVERREQUEST']._serialized_start=1386
  _globals['_UPDATESERVERREQUEST']._serialized_end=1877
  _globals['_UPDATESERVERREQUEST_LABELSENTRY']._serialized_start=1276
  _globals['_UPDATESERVERREQUEST_LABELSENTRY']._serialized_end=1321
  _globals['_NETWORKINTERFACESPEC']._serialized_start=1880
  _globals['_NETWORKINTERFACESPEC']._serialized_end=2137
  _globals['_UPDATESERVERMETADATA']._serialized_start=2139
  _globals['_UPDATESERVERMETADATA']._serialized_end=2180
  _globals['_DELETESERVERREQUEST']._serialized_start=2182
  _globals['_DELETESERVERREQUEST']._serialized_end=2248
  _globals['_DELETESERVERMETADATA']._serialized_start=2250
  _globals['_DELETESERVERMETADATA']._serialized_end=2291
  _globals['_POWEROFFSERVERREQUEST']._serialized_start=2293
  _globals['_POWEROFFSERVERREQUEST']._serialized_end=2361
  _globals['_POWEROFFSERVERMETADATA']._serialized_start=2363
  _globals['_POWEROFFSERVERMETADATA']._serialized_end=2406
  _globals['_POWERONSERVERREQUEST']._serialized_start=2408
  _globals['_POWERONSERVERREQUEST']._serialized_end=2475
  _globals['_POWERONSERVERMETADATA']._serialized_start=2477
  _globals['_POWERONSERVERMETADATA']._serialized_end=2519
  _globals['_REBOOTSERVERREQUEST']._serialized_start=2521
  _globals['_REBOOTSERVERREQUEST']._serialized_end=2587
  _globals['_REBOOTSERVERMETADATA']._serialized_start=2589
  _globals['_REBOOTSERVERMETADATA']._serialized_end=2630
  _globals['_REINSTALLSERVERREQUEST']._serialized_start=2633
  _globals['_REINSTALLSERVERREQUEST']._serialized_end=2800
  _globals['_REINSTALLSERVERMETADATA']._serialized_start=2802
  _globals['_REINSTALLSERVERMETADATA']._serialized_end=2846
  _globals['_LISTSERVEROPERATIONSREQUEST']._serialized_start=2849
  _globals['_LISTSERVEROPERATIONSREQUEST']._serialized_end=2979
  _globals['_LISTSERVEROPERATIONSRESPONSE']._serialized_start=2981
  _globals['_LISTSERVEROPERATIONSRESPONSE']._serialized_end=3097
  _globals['_BATCHCREATESERVERSREQUEST']._serialized_start=3100
  _globals['_BATCHCREATESERVERSREQUEST']._serialized_end=3803
  _globals['_BATCHCREATESERVERSREQUEST_LABELSENTRY']._serialized_start=1276
  _globals['_BATCHCREATESERVERSREQUEST_LABELSENTRY']._serialized_end=1321
  _globals['_BATCHCREATESERVERSRESPONSE']._serialized_start=3805
  _globals['_BATCHCREATESERVERSRESPONSE']._serialized_end=3890
  _globals['_BATCHCREATESERVERSMETADATA']._serialized_start=3892
  _globals['_BATCHCREATESERVERSMETADATA']._serialized_end=3940
  _globals['_QUARANTINESERVERMETADATA']._serialized_start=3942
  _globals['_QUARANTINESERVERMETADATA']._serialized_end=3987
  _globals['_STARTPROLONGATIONREQUEST']._serialized_start=3989
  _globals['_STARTPROLONGATIONREQUEST']._serialized_end=4060
  _globals['_STOPPROLONGATIONREQUEST']._serialized_start=4062
  _globals['_STOPPROLONGATIONREQUEST']._serialized_end=4132
  _globals['_SERVERSETPROLONGATIONMETADATA']._serialized_start=4134
  _globals['_SERVERSETPROLONGATIONMETADATA']._serialized_end=4184
  _globals['_OSSETTINGSSPEC']._serialized_start=4187
  _globals['_OSSETTINGSSPEC']._serialized_end=4549
  _globals['_LOCKBOXSECRET']._serialized_start=4551
  _globals['_LOCKBOXSECRET']._serialized_end=4630
  _globals['_SERVERSERVICE']._serialized_start=4633
  _globals['_SERVERSERVICE']._serialized_end=7019
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LoudnessNormalizationType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LoudnessNormalizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LoudnessNormalizationType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED: _LoudnessNormalizationType.ValueType  # 0
    """Unspecified loudness normalization. The default behavior will be used."""
    MAX_PEAK: _LoudnessNormalizationType.ValueType  # 1
    """The type of normalization, wherein the gain is changed to bring the highest PCM sample value or analog signal peak to a given level."""
    LUFS: _LoudnessNormalizationType.ValueType  # 2
    """The type of normalization based on EBU R 128 recommendation."""

class LoudnessNormalizationType(_LoudnessNormalizationType, metaclass=_LoudnessNormalizationTypeEnumTypeWrapper):
    """Specifies the loudness normalization algorithm to use when synthesizing audio."""

LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED: LoudnessNormalizationType.ValueType  # 0
"""Unspecified loudness normalization. The default behavior will be used."""
MAX_PEAK: LoudnessNormalizationType.ValueType  # 1
"""The type of normalization, wherein the gain is changed to bring the highest PCM sample value or analog signal peak to a given level."""
LUFS: LoudnessNormalizationType.ValueType  # 2
"""The type of normalization based on EBU R 128 recommendation."""
global___LoudnessNormalizationType = LoudnessNormalizationType

@typing.final
class AudioContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    AUDIO_SPEC_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Bytes with audio data."""
    @property
    def audio_spec(self) -> global___AudioFormatOptions:
        """Description of the audio format."""

    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        audio_spec: global___AudioFormatOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["AudioSource", b"AudioSource", "audio_spec", b"audio_spec", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["AudioSource", b"AudioSource", "audio_spec", b"audio_spec", "content", b"content"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["AudioSource", b"AudioSource"]) -> typing.Literal["content"] | None: ...

global___AudioContent = AudioContent

@typing.final
class AudioFormatOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_AUDIO_FIELD_NUMBER: builtins.int
    CONTAINER_AUDIO_FIELD_NUMBER: builtins.int
    @property
    def raw_audio(self) -> global___RawAudio:
        """The audio format specified in request parameters."""

    @property
    def container_audio(self) -> global___ContainerAudio:
        """The audio format specified inside the container metadata."""

    def __init__(
        self,
        *,
        raw_audio: global___RawAudio | None = ...,
        container_audio: global___ContainerAudio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["AudioFormat", b"AudioFormat", "container_audio", b"container_audio", "raw_audio", b"raw_audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["AudioFormat", b"AudioFormat", "container_audio", b"container_audio", "raw_audio", b"raw_audio"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["AudioFormat", b"AudioFormat"]) -> typing.Literal["raw_audio", "container_audio"] | None: ...

global___AudioFormatOptions = AudioFormatOptions

@typing.final
class RawAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AudioEncoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AudioEncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RawAudio._AudioEncoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUDIO_ENCODING_UNSPECIFIED: RawAudio._AudioEncoding.ValueType  # 0
        LINEAR16_PCM: RawAudio._AudioEncoding.ValueType  # 1
        """Audio bit depth 16-bit signed little-endian (Linear PCM)."""

    class AudioEncoding(_AudioEncoding, metaclass=_AudioEncodingEnumTypeWrapper): ...
    AUDIO_ENCODING_UNSPECIFIED: RawAudio.AudioEncoding.ValueType  # 0
    LINEAR16_PCM: RawAudio.AudioEncoding.ValueType  # 1
    """Audio bit depth 16-bit signed little-endian (Linear PCM)."""

    AUDIO_ENCODING_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_HERTZ_FIELD_NUMBER: builtins.int
    audio_encoding: global___RawAudio.AudioEncoding.ValueType
    """Encoding type."""
    sample_rate_hertz: builtins.int
    """Sampling frequency of the signal."""
    def __init__(
        self,
        *,
        audio_encoding: global___RawAudio.AudioEncoding.ValueType = ...,
        sample_rate_hertz: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audio_encoding", b"audio_encoding", "sample_rate_hertz", b"sample_rate_hertz"]) -> None: ...

global___RawAudio = RawAudio

@typing.final
class ContainerAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ContainerAudioType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ContainerAudioTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContainerAudio._ContainerAudioType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONTAINER_AUDIO_TYPE_UNSPECIFIED: ContainerAudio._ContainerAudioType.ValueType  # 0
        WAV: ContainerAudio._ContainerAudioType.ValueType  # 1
        """Audio bit depth 16-bit signed little-endian (Linear PCM)."""
        OGG_OPUS: ContainerAudio._ContainerAudioType.ValueType  # 2
        """Data is encoded using the OPUS audio codec and compressed using the OGG container format."""
        MP3: ContainerAudio._ContainerAudioType.ValueType  # 3
        """Data is encoded using MPEG-1/2 Layer III and compressed using the MP3 container format."""

    class ContainerAudioType(_ContainerAudioType, metaclass=_ContainerAudioTypeEnumTypeWrapper): ...
    CONTAINER_AUDIO_TYPE_UNSPECIFIED: ContainerAudio.ContainerAudioType.ValueType  # 0
    WAV: ContainerAudio.ContainerAudioType.ValueType  # 1
    """Audio bit depth 16-bit signed little-endian (Linear PCM)."""
    OGG_OPUS: ContainerAudio.ContainerAudioType.ValueType  # 2
    """Data is encoded using the OPUS audio codec and compressed using the OGG container format."""
    MP3: ContainerAudio.ContainerAudioType.ValueType  # 3
    """Data is encoded using MPEG-1/2 Layer III and compressed using the MP3 container format."""

    CONTAINER_AUDIO_TYPE_FIELD_NUMBER: builtins.int
    container_audio_type: global___ContainerAudio.ContainerAudioType.ValueType
    def __init__(
        self,
        *,
        container_audio_type: global___ContainerAudio.ContainerAudioType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_audio_type", b"container_audio_type"]) -> None: ...

global___ContainerAudio = ContainerAudio

@typing.final
class TextVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_NAME_FIELD_NUMBER: builtins.int
    VARIABLE_VALUE_FIELD_NUMBER: builtins.int
    variable_name: builtins.str
    """The name of the variable."""
    variable_value: builtins.str
    """The text of the variable."""
    def __init__(
        self,
        *,
        variable_name: builtins.str = ...,
        variable_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["variable_name", b"variable_name", "variable_value", b"variable_value"]) -> None: ...

global___TextVariable = TextVariable

@typing.final
class AudioVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_NAME_FIELD_NUMBER: builtins.int
    VARIABLE_START_MS_FIELD_NUMBER: builtins.int
    VARIABLE_LENGTH_MS_FIELD_NUMBER: builtins.int
    variable_name: builtins.str
    """The name of the variable."""
    variable_start_ms: builtins.int
    """Start time of the variable in milliseconds."""
    variable_length_ms: builtins.int
    """Length of the variable in milliseconds."""
    def __init__(
        self,
        *,
        variable_name: builtins.str = ...,
        variable_start_ms: builtins.int = ...,
        variable_length_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["variable_length_ms", b"variable_length_ms", "variable_name", b"variable_name", "variable_start_ms", b"variable_start_ms"]) -> None: ...

global___AudioVariable = AudioVariable

@typing.final
class UtteranceSynthesisResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_CHUNK_FIELD_NUMBER: builtins.int
    TEXT_CHUNK_FIELD_NUMBER: builtins.int
    START_MS_FIELD_NUMBER: builtins.int
    LENGTH_MS_FIELD_NUMBER: builtins.int
    start_ms: builtins.int
    """Start time of the audio chunk in milliseconds."""
    length_ms: builtins.int
    """Length of the audio chunk in milliseconds."""
    @property
    def audio_chunk(self) -> global___AudioChunk:
        """Part of synthesized audio."""

    @property
    def text_chunk(self) -> global___TextChunk:
        """Part of synthesized text."""

    def __init__(
        self,
        *,
        audio_chunk: global___AudioChunk | None = ...,
        text_chunk: global___TextChunk | None = ...,
        start_ms: builtins.int = ...,
        length_ms: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_chunk", b"audio_chunk", "text_chunk", b"text_chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_chunk", b"audio_chunk", "length_ms", b"length_ms", "start_ms", b"start_ms", "text_chunk", b"text_chunk"]) -> None: ...

global___UtteranceSynthesisResponse = UtteranceSynthesisResponse

@typing.final
class AudioTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    TEXT_TEMPLATE_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> global___AudioContent:
        """Audio file."""

    @property
    def text_template(self) -> global___TextTemplate:
        """Template and description of its variables."""

    @property
    def variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioVariable]:
        """Describing variables in audio."""

    def __init__(
        self,
        *,
        audio: global___AudioContent | None = ...,
        text_template: global___TextTemplate | None = ...,
        variables: collections.abc.Iterable[global___AudioVariable] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "text_template", b"text_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "text_template", b"text_template", "variables", b"variables"]) -> None: ...

global___AudioTemplate = AudioTemplate

@typing.final
class AudioChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    """Sequence of bytes of the synthesized audio in format specified in output_audio_spec."""
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data"]) -> None: ...

global___AudioChunk = AudioChunk

@typing.final
class TextChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Synthesized text."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

global___TextChunk = TextChunk

@typing.final
class TextTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_TEMPLATE_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    text_template: builtins.str
    """Template text.

    Sample:`The {animal} goes to the {place}.`
    """
    @property
    def variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextVariable]:
        """Defining variables in template text.

        Sample: `{animal: cat, place: forest}`
        """

    def __init__(
        self,
        *,
        text_template: builtins.str = ...,
        variables: collections.abc.Iterable[global___TextVariable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text_template", b"text_template", "variables", b"variables"]) -> None: ...

global___TextTemplate = TextTemplate

@typing.final
class DurationHint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DurationHintPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DurationHintPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DurationHint._DurationHintPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DURATION_HINT_POLICY_UNSPECIFIED: DurationHint._DurationHintPolicy.ValueType  # 0
        EXACT_DURATION: DurationHint._DurationHintPolicy.ValueType  # 1
        """Limit audio duration to exact value."""
        MIN_DURATION: DurationHint._DurationHintPolicy.ValueType  # 2
        """Limit the minimum audio duration."""
        MAX_DURATION: DurationHint._DurationHintPolicy.ValueType  # 3
        """Limit the maximum audio duration."""

    class DurationHintPolicy(_DurationHintPolicy, metaclass=_DurationHintPolicyEnumTypeWrapper): ...
    DURATION_HINT_POLICY_UNSPECIFIED: DurationHint.DurationHintPolicy.ValueType  # 0
    EXACT_DURATION: DurationHint.DurationHintPolicy.ValueType  # 1
    """Limit audio duration to exact value."""
    MIN_DURATION: DurationHint.DurationHintPolicy.ValueType  # 2
    """Limit the minimum audio duration."""
    MAX_DURATION: DurationHint.DurationHintPolicy.ValueType  # 3
    """Limit the maximum audio duration."""

    POLICY_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    policy: global___DurationHint.DurationHintPolicy.ValueType
    """Type of duration constraint."""
    duration_ms: builtins.int
    """Constraint on audio duration in milliseconds."""
    def __init__(
        self,
        *,
        policy: global___DurationHint.DurationHintPolicy.ValueType = ...,
        duration_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duration_ms", b"duration_ms", "policy", b"policy"]) -> None: ...

global___DurationHint = DurationHint

@typing.final
class Hints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICE_FIELD_NUMBER: builtins.int
    AUDIO_TEMPLATE_FIELD_NUMBER: builtins.int
    SPEED_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    PITCH_SHIFT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    voice: builtins.str
    """Name of speaker to use."""
    speed: builtins.float
    """Hint to change speed."""
    volume: builtins.float
    """Hint to regulate normalization level.
    * For `MAX_PEAK` loudness_normalization_type: volume changes in a range (0;1], default value is 0.7.
    * For `LUFS` loudness_normalization_type: volume changes in a range [-145;0), default value is -19.
    """
    role: builtins.str
    """Hint to specify pronunciation character for the speaker."""
    pitch_shift: builtins.float
    """Hint to increase (or decrease) speaker's pitch, measured in Hz. Valid values are in range [-1000;1000], default value is 0."""
    @property
    def audio_template(self) -> global___AudioTemplate:
        """Template for synthesizing."""

    @property
    def duration(self) -> global___DurationHint:
        """Hint to limit both minimum and maximum audio duration."""

    def __init__(
        self,
        *,
        voice: builtins.str = ...,
        audio_template: global___AudioTemplate | None = ...,
        speed: builtins.float = ...,
        volume: builtins.float = ...,
        role: builtins.str = ...,
        pitch_shift: builtins.float = ...,
        duration: global___DurationHint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Hint", b"Hint", "audio_template", b"audio_template", "duration", b"duration", "pitch_shift", b"pitch_shift", "role", b"role", "speed", b"speed", "voice", b"voice", "volume", b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Hint", b"Hint", "audio_template", b"audio_template", "duration", b"duration", "pitch_shift", b"pitch_shift", "role", b"role", "speed", b"speed", "voice", b"voice", "volume", b"volume"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Hint", b"Hint"]) -> typing.Literal["voice", "audio_template", "speed", "volume", "role", "pitch_shift", "duration"] | None: ...

global___Hints = Hints

@typing.final
class UtteranceSynthesisRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _LoudnessNormalizationType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LoudnessNormalizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UtteranceSynthesisRequest._LoudnessNormalizationType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED: UtteranceSynthesisRequest._LoudnessNormalizationType.ValueType  # 0
        MAX_PEAK: UtteranceSynthesisRequest._LoudnessNormalizationType.ValueType  # 1
        """The type of normalization, wherein the gain is changed to bring the highest PCM sample value or analog signal peak to a given level."""
        LUFS: UtteranceSynthesisRequest._LoudnessNormalizationType.ValueType  # 2
        """The type of normalization based on EBU R 128 recommendation."""

    class LoudnessNormalizationType(_LoudnessNormalizationType, metaclass=_LoudnessNormalizationTypeEnumTypeWrapper): ...
    LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED: UtteranceSynthesisRequest.LoudnessNormalizationType.ValueType  # 0
    MAX_PEAK: UtteranceSynthesisRequest.LoudnessNormalizationType.ValueType  # 1
    """The type of normalization, wherein the gain is changed to bring the highest PCM sample value or analog signal peak to a given level."""
    LUFS: UtteranceSynthesisRequest.LoudnessNormalizationType.ValueType  # 2
    """The type of normalization based on EBU R 128 recommendation."""

    MODEL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_TEMPLATE_FIELD_NUMBER: builtins.int
    HINTS_FIELD_NUMBER: builtins.int
    OUTPUT_AUDIO_SPEC_FIELD_NUMBER: builtins.int
    LOUDNESS_NORMALIZATION_TYPE_FIELD_NUMBER: builtins.int
    UNSAFE_MODE_FIELD_NUMBER: builtins.int
    model: builtins.str
    """The name of the model.
    This parameter is only required for specific functionalities, such as [SpeechKit Brand Voice Lite](/docs/speechkit/tts/brand-voice/) or SpeechKit Brand Voice Call Center. If you are not sure whether your use case needs this parameter, do not include it.
    """
    text: builtins.str
    """Raw text (e.g. "Hello, Alice")."""
    loudness_normalization_type: global___UtteranceSynthesisRequest.LoudnessNormalizationType.ValueType
    """Specifies type of loudness normalization.
    Optional. Default: `LUFS`.
    """
    unsafe_mode: builtins.bool
    """Optional. Automatically split long text to several utterances and bill accordingly. Some degradation in service quality is possible."""
    @property
    def text_template(self) -> global___TextTemplate:
        """Text template instance, e.g. `{"Hello, {username}" with username="Alice"}`."""

    @property
    def hints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Hints]:
        """Optional hints for synthesis."""

    @property
    def output_audio_spec(self) -> global___AudioFormatOptions:
        """Optional. Default: 22050 Hz, linear 16-bit signed little-endian PCM, with WAV header"""

    def __init__(
        self,
        *,
        model: builtins.str = ...,
        text: builtins.str = ...,
        text_template: global___TextTemplate | None = ...,
        hints: collections.abc.Iterable[global___Hints] | None = ...,
        output_audio_spec: global___AudioFormatOptions | None = ...,
        loudness_normalization_type: global___UtteranceSynthesisRequest.LoudnessNormalizationType.ValueType = ...,
        unsafe_mode: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Utterance", b"Utterance", "output_audio_spec", b"output_audio_spec", "text", b"text", "text_template", b"text_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Utterance", b"Utterance", "hints", b"hints", "loudness_normalization_type", b"loudness_normalization_type", "model", b"model", "output_audio_spec", b"output_audio_spec", "text", b"text", "text_template", b"text_template", "unsafe_mode", b"unsafe_mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Utterance", b"Utterance"]) -> typing.Literal["text", "text_template"] | None: ...

global___UtteranceSynthesisRequest = UtteranceSynthesisRequest

@typing.final
class SynthesisOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    VOICE_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SPEED_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    PITCH_SHIFT_FIELD_NUMBER: builtins.int
    OUTPUT_AUDIO_SPEC_FIELD_NUMBER: builtins.int
    LOUDNESS_NORMALIZATION_TYPE_FIELD_NUMBER: builtins.int
    model: builtins.str
    """The name of the TTS model to use for synthesis. Currently should be empty. Do not use it."""
    voice: builtins.str
    """The voice to use for speech synthesis."""
    role: builtins.str
    """The role or speaking style. Can be used to specify pronunciation character for the speaker."""
    speed: builtins.float
    """Speed multiplier (default: 1.0)."""
    volume: builtins.float
    """Volume adjustment:
    * For `MAX_PEAK`: range is (0, 1], default 0.7.
    * For `LUFS`: range is [-145, 0), default -19.
    """
    pitch_shift: builtins.float
    """Pitch adjustment, in Hz, range [-1000, 1000], default 0."""
    loudness_normalization_type: global___LoudnessNormalizationType.ValueType
    """Loudness normalization type for output (default: `LUFS`)."""
    @property
    def output_audio_spec(self) -> global___AudioFormatOptions:
        """Specifies output audio format. Default: 22050Hz, linear 16-bit signed little-endian PCM, with WAV header."""

    def __init__(
        self,
        *,
        model: builtins.str = ...,
        voice: builtins.str = ...,
        role: builtins.str = ...,
        speed: builtins.float = ...,
        volume: builtins.float = ...,
        pitch_shift: builtins.float = ...,
        output_audio_spec: global___AudioFormatOptions | None = ...,
        loudness_normalization_type: global___LoudnessNormalizationType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output_audio_spec", b"output_audio_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["loudness_normalization_type", b"loudness_normalization_type", "model", b"model", "output_audio_spec", b"output_audio_spec", "pitch_shift", b"pitch_shift", "role", b"role", "speed", b"speed", "voice", b"voice", "volume", b"volume"]) -> None: ...

global___SynthesisOptions = SynthesisOptions

@typing.final
class SynthesisInput(google.protobuf.message.Message):
    """The input for synthesis."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """The text string to be synthesized."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

global___SynthesisInput = SynthesisInput

@typing.final
class ForceSynthesisEvent(google.protobuf.message.Message):
    """Event to forcibly trigger synthesis."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ForceSynthesisEvent = ForceSynthesisEvent

@typing.final
class StreamSynthesisRequest(google.protobuf.message.Message):
    """Sent by client to control or provide data during streaming synthesis."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    SYNTHESIS_INPUT_FIELD_NUMBER: builtins.int
    FORCE_SYNTHESIS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___SynthesisOptions:
        """Synthesis options. Must be provided in the first request of the stream and cannot be updated afterwards."""

    @property
    def synthesis_input(self) -> global___SynthesisInput:
        """Input to be synthesized."""

    @property
    def force_synthesis(self) -> global___ForceSynthesisEvent:
        """Triggers immediate synthesis of buffered input."""

    def __init__(
        self,
        *,
        options: global___SynthesisOptions | None = ...,
        synthesis_input: global___SynthesisInput | None = ...,
        force_synthesis: global___ForceSynthesisEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Event", b"Event", "force_synthesis", b"force_synthesis", "options", b"options", "synthesis_input", b"synthesis_input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Event", b"Event", "force_synthesis", b"force_synthesis", "options", b"options", "synthesis_input", b"synthesis_input"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Event", b"Event"]) -> typing.Literal["options", "synthesis_input", "force_synthesis"] | None: ...

global___StreamSynthesisRequest = StreamSynthesisRequest

@typing.final
class StreamSynthesisResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_CHUNK_FIELD_NUMBER: builtins.int
    TEXT_CHUNK_FIELD_NUMBER: builtins.int
    START_MS_FIELD_NUMBER: builtins.int
    LENGTH_MS_FIELD_NUMBER: builtins.int
    start_ms: builtins.int
    """Start time of the audio chunk in milliseconds."""
    length_ms: builtins.int
    """Length of the audio chunk in milliseconds."""
    @property
    def audio_chunk(self) -> global___AudioChunk:
        """Part of synthesized audio."""

    @property
    def text_chunk(self) -> global___TextChunk:
        """Part of synthesized text."""

    def __init__(
        self,
        *,
        audio_chunk: global___AudioChunk | None = ...,
        text_chunk: global___TextChunk | None = ...,
        start_ms: builtins.int = ...,
        length_ms: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_chunk", b"audio_chunk", "text_chunk", b"text_chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_chunk", b"audio_chunk", "length_ms", b"length_ms", "start_ms", b"start_ms", "text_chunk", b"text_chunk"]) -> None: ...

global___StreamSynthesisResponse = StreamSynthesisResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.iam.v1.key_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _KeyFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KeyFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KeyFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PEM_FILE: _KeyFormat.ValueType  # 0
    """Privacy-Enhanced Mail (PEM) format. Default value."""

class KeyFormat(_KeyFormat, metaclass=_KeyFormatEnumTypeWrapper): ...

PEM_FILE: KeyFormat.ValueType  # 0
"""Privacy-Enhanced Mail (PEM) format. Default value."""
global___KeyFormat = KeyFormat

@typing.final
class GetKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the Key resource to return.
    To get the ID use a [KeyService.List] request.
    """
    format: global___KeyFormat.ValueType
    """Output format of the key."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        format: global___KeyFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format", b"format", "key_id", b"key_id"]) -> None: ...

global___GetKeyRequest = GetKeyRequest

@typing.final
class ListKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    format: global___KeyFormat.ValueType
    """Output format of the key."""
    service_account_id: builtins.str
    """ID of the service account to list key pairs for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListKeysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListKeysResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        format: global___KeyFormat.ValueType = ...,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format", b"format", "page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListKeysRequest = ListKeysRequest

@typing.final
class ListKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListKeysRequest.page_size], use
    the [next_page_token] as the value
    for the [ListKeysRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.key_pb2.Key]:
        """List of Key resources."""

    def __init__(
        self,
        *,
        keys: collections.abc.Iterable[yandex.cloud.iam.v1.key_pb2.Key] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keys", b"keys", "next_page_token", b"next_page_token"]) -> None: ...

global___ListKeysResponse = ListKeysResponse

@typing.final
class CreateKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to create a key pair for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    """
    description: builtins.str
    """Description of the key pair."""
    format: global___KeyFormat.ValueType
    """Output format of the key."""
    key_algorithm: yandex.cloud.iam.v1.key_pb2.Key.Algorithm.ValueType
    """An algorithm used to generate a key pair of the Key resource."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        description: builtins.str = ...,
        format: global___KeyFormat.ValueType = ...,
        key_algorithm: yandex.cloud.iam.v1.key_pb2.Key.Algorithm.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "format", b"format", "key_algorithm", b"key_algorithm", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateKeyRequest = CreateKeyRequest

@typing.final
class CreateKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    private_key: builtins.str
    """A private key of the Key resource.
    This key must be stored securely.
    """
    @property
    def key(self) -> yandex.cloud.iam.v1.key_pb2.Key:
        """Key resource."""

    def __init__(
        self,
        *,
        key: yandex.cloud.iam.v1.key_pb2.Key | None = ...,
        private_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "private_key", b"private_key"]) -> None: ...

global___CreateKeyResponse = CreateKeyResponse

@typing.final
class UpdateKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the Key resource to update.
    To get key pair ID, use a [KeyService.List] request.
    """
    description: builtins.str
    """Description of the key pair."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Key resource are going to be updated."""

    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "key_id", b"key_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateKeyRequest = UpdateKeyRequest

@typing.final
class UpdateKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the Key resource that is being updated."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___UpdateKeyMetadata = UpdateKeyMetadata

@typing.final
class DeleteKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to delete.
    To get key ID use a [KeyService.List] request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteKeyRequest = DeleteKeyRequest

@typing.final
class DeleteKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key that is being deleted."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteKeyMetadata = DeleteKeyMetadata

@typing.final
class ListKeyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListKeyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListKeyOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListKeyOperationsRequest = ListKeyOperationsRequest

@typing.final
class ListKeyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListKeyOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListKeyOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified key."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListKeyOperationsResponse = ListKeyOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/security_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/security_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import security_group_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/vpc/v1/security_group_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/vpc/v1/security_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x17GetSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"k\n\x19ListSecurityGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"r\n\x1aListSecurityGroupsResponse\x12;\n\x0fsecurity_groups\x18\x01 \x03(\x0b\x32\".yandex.cloud.vpc.v1.SecurityGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb7\x03\n\x1a\x43reateSecurityGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x18\n\nnetwork_id\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12>\n\nrule_specs\x18\x06 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x04\n\x15SecurityGroupRuleSpec\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12I\n\tdirection\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.vpc.v1.SecurityGroupRule.DirectionB\x04\xe8\xc7\x31\x01\x12-\n\x05ports\x18\x04 \x01(\x0b\x32\x1e.yandex.cloud.vpc.v1.PortRange\x12\x17\n\rprotocol_name\x18\x05 \x01(\tH\x00\x12\x19\n\x0fprotocol_number\x18\x06 \x01(\x03H\x00\x12\x36\n\x0b\x63idr_blocks\x18\x07 \x01(\x0b\x32\x1f.yandex.cloud.vpc.v1.CidrBlocksH\x01\x12\x1b\n\x11security_group_id\x18\x08 \x01(\tH\x01\x12\x1b\n\x11predefined_target\x18\t \x01(\tH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08protocolB\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"8\n\x1b\x43reateSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\"\xd6\x03\n\x1aUpdateSecurityGroupRequest\x12\'\n\x11security_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12>\n\nrule_specs\x18\x06 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x1bUpdateSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64\x64\x65\x64_rule_ids\x18\x02 \x03(\t\"\xa6\x01\n\x1fUpdateSecurityGroupRulesRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x11\x64\x65letion_rule_ids\x18\x02 \x03(\t\x12G\n\x13\x61\x64\x64ition_rule_specs\x18\x03 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\"\x9e\x02\n\x1eUpdateSecurityGroupRuleRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07rule_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12O\n\x06labels\x18\x05 \x03(\x0b\x32?.yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x1fUpdateSecurityGroupRuleMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"8\n\x1b\x44\x65leteSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\"l\n\"ListSecurityGroupOperationsRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"u\n#ListSecurityGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"`\n\x18MoveSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12#\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x19MoveSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t2\xb7\r\n\x14SecurityGroupService\x12\x8b\x01\n\x03Get\x12,.yandex.cloud.vpc.v1.GetSecurityGroupRequest\x1a\".yandex.cloud.vpc.v1.SecurityGroup\"2\x82\xd3\xe4\x93\x02,\x12*/vpc/v1/securityGroups/{security_group_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.vpc.v1.ListSecurityGroupsRequest\x1a/.yandex.cloud.vpc.v1.ListSecurityGroupsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/vpc/v1/securityGroups\x12\xaf\x01\n\x06\x43reate\x12/.yandex.cloud.vpc.v1.CreateSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2*,\n\x1b\x43reateSecurityGroupMetadata\x12\rSecurityGroup\x82\xd3\xe4\x93\x02\x1b\"\x16/vpc/v1/securityGroups:\x01*\x12\xc3\x01\n\x06Update\x12/.yandex.cloud.vpc.v1.UpdateSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*,\n\x1bUpdateSecurityGroupMetadata\x12\rSecurityGroup\x82\xd3\xe4\x93\x02/2*/vpc/v1/securityGroups/{security_group_id}:\x01*\x12\xd3\x01\n\x0bUpdateRules\x12\x34.yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*,\n\x1bUpdateSecurityGroupMetadata\x12\rSecurityGroup\x82\xd3\xe4\x93\x02\x35\x32\x30/vpc/v1/securityGroups/{security_group_id}/rules:\x01*\x12\xe3\x01\n\nUpdateRule\x12\x33.yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*4\n\x1fUpdateSecurityGroupRuleMetadata\x12\x11SecurityGroupRule\x82\xd3\xe4\x93\x02?2:/vpc/v1/securityGroups/{security_group_id}/rules/{rule_id}:\x01*\x12\xc8\x01\n\x06\x44\x65lete\x12/.yandex.cloud.vpc.v1.DeleteSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*4\n\x1b\x44\x65leteSecurityGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02,**/vpc/v1/securityGroups/{security_group_id}\x12\xc2\x01\n\x04Move\x12-.yandex.cloud.vpc.v1.MoveSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"h\xb2\xd2**\n\x19MoveSecurityGroupMetadata\x12\rSecurityGroup\x82\xd3\xe4\x93\x02\x34\"//vpc/v1/securityGroups/{security_group_id}:move:\x01*\x12\xc2\x01\n\x0eListOperations\x12\x37.yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest\x1a\x38.yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/vpc/v1/securityGroups/{security_group_id}/operationsBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.security_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _globals['_GETSECURITYGROUPREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_GETSECURITYGROUPREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTSECURITYGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSECURITYGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATESECURITYGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATESECURITYGROUPREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _globals['_SECURITYGROUPRULESPEC_LABELSENTRY']._loaded_options = None
  _globals['_SECURITYGROUPRULESPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYGROUPRULESPEC'].oneofs_by_name['target']._loaded_options = None
  _globals['_SECURITYGROUPRULESPEC'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['description']._loaded_options = None
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['direction']._loaded_options = None
  _globals['_SECURITYGROUPRULESPEC'].fields_by_name['direction']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESECURITYGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATESECURITYGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATESECURITYGROUPRULESREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_UPDATESECURITYGROUPRULESREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESECURITYGROUPRULEREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_UPDATESECURITYGROUPRULEREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESECURITYGROUPRULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATESECURITYGROUPRULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_DELETESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTSECURITYGROUPOPERATIONSREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_LISTSECURITYGROUPOPERATIONSREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_MOVESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._loaded_options = None
  _globals['_MOVESECURITYGROUPREQUEST'].fields_by_name['security_group_id']._serialized_options = b'\350\3071\001'
  _globals['_MOVESECURITYGROUPREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVESECURITYGROUPREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002,\022*/vpc/v1/securityGroups/{security_group_id}'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/vpc/v1/securityGroups'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*,\n\033CreateSecurityGroupMetadata\022\rSecurityGroup\202\323\344\223\002\033\"\026/vpc/v1/securityGroups:\001*'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*,\n\033UpdateSecurityGroupMetadata\022\rSecurityGroup\202\323\344\223\002/2*/vpc/v1/securityGroups/{security_group_id}:\001*'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['UpdateRules']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['UpdateRules']._serialized_options = b'\262\322*,\n\033UpdateSecurityGroupMetadata\022\rSecurityGroup\202\323\344\223\002520/vpc/v1/securityGroups/{security_group_id}/rules:\001*'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['UpdateRule']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['UpdateRule']._serialized_options = b'\262\322*4\n\037UpdateSecurityGroupRuleMetadata\022\021SecurityGroupRule\202\323\344\223\002?2:/vpc/v1/securityGroups/{security_group_id}/rules/{rule_id}:\001*'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*4\n\033DeleteSecurityGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002,**/vpc/v1/securityGroups/{security_group_id}'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322**\n\031MoveSecurityGroupMetadata\022\rSecurityGroup\202\323\344\223\0024\"//vpc/v1/securityGroups/{security_group_id}:move:\001*'
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_SECURITYGROUPSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0027\0225/vpc/v1/securityGroups/{security_group_id}/operations'
  _globals['_GETSECURITYGROUPREQUEST']._serialized_start=284
  _globals['_GETSECURITYGROUPREQUEST']._serialized_end=342
  _globals['_LISTSECURITYGROUPSREQUEST']._serialized_start=344
  _globals['_LISTSECURITYGROUPSREQUEST']._serialized_end=451
  _globals['_LISTSECURITYGROUPSRESPONSE']._serialized_start=453
  _globals['_LISTSECURITYGROUPSRESPONSE']._serialized_end=567
  _globals['_CREATESECURITYGROUPREQUEST']._serialized_start=570
  _globals['_CREATESECURITYGROUPREQUEST']._serialized_end=1009
  _globals['_CREATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_start=964
  _globals['_CREATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_end=1009
  _globals['_SECURITYGROUPRULESPEC']._serialized_start=1012
  _globals['_SECURITYGROUPRULESPEC']._serialized_end=1572
  _globals['_SECURITYGROUPRULESPEC_LABELSENTRY']._serialized_start=964
  _globals['_SECURITYGROUPRULESPEC_LABELSENTRY']._serialized_end=1009
  _globals['_CREATESECURITYGROUPMETADATA']._serialized_start=1574
  _globals['_CREATESECURITYGROUPMETADATA']._serialized_end=1630
  _globals['_UPDATESECURITYGROUPREQUEST']._serialized_start=1633
  _globals['_UPDATESECURITYGROUPREQUEST']._serialized_end=2103
  _globals['_UPDATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_start=964
  _globals['_UPDATESECURITYGROUPREQUEST_LABELSENTRY']._serialized_end=1009
  _globals['_UPDATESECURITYGROUPMETADATA']._serialized_start=2105
  _globals['_UPDATESECURITYGROUPMETADATA']._serialized_end=2185
  _globals['_UPDATESECURITYGROUPRULESREQUEST']._serialized_start=2188
  _globals['_UPDATESECURITYGROUPRULESREQUEST']._serialized_end=2354
  _globals['_UPDATESECURITYGROUPRULEREQUEST']._serialized_start=2357
  _globals['_UPDATESECURITYGROUPRULEREQUEST']._serialized_end=2643
  _globals['_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY']._serialized_start=964
  _globals['_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY']._serialized_end=1009
  _globals['_UPDATESECURITYGROUPRULEMETADATA']._serialized_start=2645
  _globals['_UPDATESECURITYGROUPRULEMETADATA']._serialized_end=2722
  _globals['_DELETESECURITYGROUPREQUEST']._serialized_start=2724
  _globals['_DELETESECURITYGROUPREQUEST']._serialized_end=2785
  _globals['_DELETESECURITYGROUPMETADATA']._serialized_start=2787
  _globals['_DELETESECURITYGROUPMETADATA']._serialized_end=2843
  _globals['_LISTSECURITYGROUPOPERATIONSREQUEST']._serialized_start=2845
  _globals['_LISTSECURITYGROUPOPERATIONSREQUEST']._serialized_end=2953
  _globals['_LISTSECURITYGROUPOPERATIONSRESPONSE']._serialized_start=2955
  _globals['_LISTSECURITYGROUPOPERATIONSRESPONSE']._serialized_end=3072
  _globals['_MOVESECURITYGROUPREQUEST']._serialized_start=3074
  _globals['_MOVESECURITYGROUPREQUEST']._serialized_end=3170
  _globals['_MOVESECURITYGROUPMETADATA']._serialized_start=3172
  _globals['_MOVESECURITYGROUPMETADATA']._serialized_end=3226
  _globals['_SECURITYGROUPSERVICE']._serialized_start=3229
  _globals['_SECURITYGROUPSERVICE']._serialized_end=4948
# @@protoc_insertion_point(module_scope)
